@@ -13,7 +13,7 @@ use Modern::Perl;    ## no critic (UselessNoCritic RequireExplicitPackage)
 package SVN::Simple::Hook;
 
 BEGIN {
-    $SVN::Simple::Hook::VERSION = '0.110070';
+    $SVN::Simple::Hook::VERSION = '0.110071';
 }
 
 # ABSTRACT: Simple Moose-based framework for Subversion hooks
@@ -55,26 +55,32 @@ SVN::Simple::Hook - Simple Moose-based framework for Subversion hooks
 
 =head1 VERSION
 
-version 0.110070
+version 0.110071
 
 =head1 SYNOPSIS
 
-    package MyHook;
-    
-    use Moose;
-    extends 'MooseX::App::Cmd::Command';
-    with 'SVN::Simple::Hook';
-    
-    1;
-
 =head1 DESCRIPTION
 
+This is a collection of L<Moose::Role|Moose::Role>s that help you implement
+Subversion repository hooks by providing simple attribute access to relevant
+parts of the Subversion API.  This is a work in progress and the interface
+is extremely unstable at the moment.  You have been warned!
+
 =head1 ATTRIBUTES
 
 =head2 repos_path
 
 L<Directory|Path::Class::Dir> containing the Subversion repository.
 
+=for test_synopsis 1;
+
+=for test_synopsis __END__
+
+=head1 SEE ALSO
+
+See L<SVN::Simple::Hook::PreCommit|SVN::Simple::Hook::PreCommit/SYNOPSIS> for
+an example.  This role exists solely to be composed into other roles.
+
 =head1 AUTHOR
 
 Mark Gardner <mjgardner@cpan.org>
